#include "ki/sys.h"
#include "ki/error.h"
#include "ki/memory.h"
#include "ki/dynarray.h"

static Dynarray errors = { sizeof(Error), 0, NULL };

typedef (void)(ErrorHandler)(Error *error);

void ErrorRegister(size_t code, const char *msg, ErrorHandler *handler) {
  Error *error = ErrorLookup(code);

  if (!error) {
    error = DynarrayElementNew(&errors);
    error->code = code;
  }

  error->msg = msg;
  error->handler = handler;
}

Error* ErrorLookup(size_t code) {
  for (size_t i = 0; i < errors.count; i++) {
    Error *error = DynarrayIndex(&errors, i);

    if (error->code == code) {
      return error;
    }
  }

  return NULL;
}

#endif

/* vi: set et ts=2 sw=2: */

